Notebooks
========================================================================================

.. toctree::

    Minimal Getting Started <notebooks/minimal_notebook>
    Detailed Examples <notebooks/demo>
    CDF Accuracy Exploration <notebooks/cdf_demonstration>